# Changelog

<!--next-version-placeholder-->

## v1.1.5 (2021-07-05)
### Fix
* Handle empty data returned after new Fritz!Box 7490 update ([#5](https://github.com/eifinger/fritz-switch-profiles/issues/5)) ([`6230c75`](https://github.com/eifinger/fritz-switch-profiles/commit/6230c75a90df530e5c660493d67d89cde0394622))

## v1.1.4 (2021-06-15)
### Fix
* Handle empty data in device json answer ([#4](https://github.com/eifinger/fritz-switch-profiles/issues/4)) ([`f4741ef`](https://github.com/eifinger/fritz-switch-profiles/commit/f4741ef909218cb7647a00ca745e7d4b5c5d0a9c))

## v1.1.3 (2020-12-07)
### Fix
* Trigger release ([`b4e858e`](https://github.com/eifinger/fritz-switch-profiles/commit/b4e858e919c00be0439090dc2dc6b311d5e16278))
